// Persistence of Vision Raytracer 1.0 file

/*
*
*   KITCHEN.POV      8-29-91
*
*   Written by: Jim Parker
*		jparker@baks.bell-atl.com
*
*   Modified by: Brian Steuer 
*                bsteuer@cs.ucsd.edu
*   - I just converted it to POV 1.0 and cleaned it up a bit
*
*   DKBTrace scene description of a kitchen.  Lotsa ugly textures and
*   reflections that will grind your system to a quick hault. This takes
*   2.5 hours to trace on an unbridled Sun IPX (24.4 SPECmarks, 28.5MIPS,
*   4.2 MFLOPS) at 640x480.  Feel free to add appliances, textures, other
*   rooms, etc.  For example, this kitchen desperately needs a good, solid,
*   stainless-steel sink.  Fridge needs shelves and food.  Use your
*   imagination!  Ray-tracing was invented to be fun!
*
*   NEED: wallpapr.gif, snack.gif, front.gif. If these files are not included, 
*   then comment out those lines, or replace them with your own GIFs.  (The
*   wallpaper pattern could end up being very interesting!)
*
*   Something to try:  Turn off ceiling light and let light from fridge and
*   outside light illuminate the room.  Maybe make light in refrigerator
*   yellow instead of white.  Enhance nighttime effect by turning sky's colors
*   to black or even map star.gif on a plane outside windows.
*
*   This file is released into the public domain and may be used or altered
*   by anyone as desired.  I would appreciate it if any cool changes could
*   be sent to me.
*
*/



#include "shapes.inc"
#include "colors.inc"
#include "textures.inc"


#declare CTop =	object {
                    Cube
                    scale <1 0.12 1>
	            texture {
                      pigment {
			granite
                      }
     			scale <3 3 3>
                      finish {
     			specular 1
     			roughness 0.02
     			reflection 0.3
                      }
		     }
		 }


#declare BarY = object {
                  cylinder { <1 0 0> <-1 0 0> 1 }
                  rotate <0 0 90>
                }

#declare BarX =	object {
                  cylinder { <1 0 0> <-1 0 0> 1 }
		 }

#declare BarZ =	object {
                  cylinder { <1 0 0> <-1 0 0> 1 }
                  rotate <0 90 0>
		 }

/* ------------- --------------- ----------------- --------------- -------- */


camera {
   location  < 0.05  4.0   0.05>
   up 	     < 0.0   1.0   0.0>
   right     < 1.33  0.0   0.0>
   look_at   <20.0   4.0  20.0>
 }


/* Sky */

object {
   sphere { <0 -39000 0> 40000 }
   texture {
      bozo
      turbulence 0.6
      colour_map {
         [0   0.5 colour red 0.4 green 0.5 blue 1
                  colour red 0.4 green 0.5 blue 1]
         [0.5 0.7 colour red 0.4 green 0.5 blue 1
                  colour red 1   green 1   blue 1]
         [0.7 1	  colour red 1   green 1   blue 1
                  colour red 0.7 green 0.7 blue 0.7]
       }
      scale <500 500 500>
      ambient 1
      diffuse 0
    }
   colour red 0.4 green 0.5 blue 1
 }

/* Outside light */

light_source {
  <17 60 100>
  color White
}

/* Ceiling light */

light_source {
  <10 6 10>
  color White
}

object {
    BarY
    texture {
	Metal
     }
    color Grey
    scale <0.05 1 0.05>
    translate <10 9.7 10>
 }

/* Lamp shade */

object {
    intersection {
    difference {
        object {Sphere}
        object { Sphere
	    scale <0.95 0.95 0.95>
        }
     }
    plane { <0 -1 0> -0.1  }
     }
    texture {
	color Red
	alpha 0.6
     }
    color Red
    scale <1 1 1>
    rotate <0 0 0>
    translate <10 7.7 10>
 }

/* Put down cliche' checkered floor */

object {
    Cube
    texture {
	checker color Black
	        color White
	reflection 0.2
	ambient 0.1
	diffuse 0.8
	scale <0.05 0.05 0.05>
     }
    scale <10 0.15 10>
    translate <10 0 10>
 }


/* Roof */

object {
    Cube
    texture {
	color White
     }
    scale <10 0.15 10>
    translate <10 10 10>
 }


/* Four walls */

object {
    difference {
        object {
	    Cube
	    scale <10 10 0.15>
	    translate <10 10 20>
	 }
        object {
	    Cube
	    scale <1 2 1>
	    translate <17 6 20>
	 }
        object {
	    Cube
	    scale <2 3 1>
	    translate <4 3 20>
	 }
     }
    texture {
	/* the next line was original: IMAGEMAP GIF "wallpapr.gif" */
/*        image_map { gif "stars.gif" } */
      color Blue
     }
 }

object {
    Cube
    texture {
	color Green
     }
    scale <0.15 10 10>
    translate <-1 10 10>
 }

/* Right wall */

object {
    Cube
    texture {
	color Green
     }
    scale <0.15 10 10>
    translate <20 10 10>
 }

object {
    Cube
    texture {
	color Green
     }
    scale <10 10 0.15>
    translate <10 10 -1>
 }


/* Right cabinets */

object {
    CTop
    scale <2 1 9>
    translate <19 3 17.5>
 }

object {
    Cube
    texture {
	Tom_Wood
	dents 0.1
	scale 0.1
     }
    color White
    scale <1.9 1.5 8.9>
    translate <19 1.5 17.5>
 }

/* Doors */

object {
    Cube
    texture {
	Tom_Wood
	dents 0.1
	scale 0.1
     }
    color White
    scale <0.04 1.2 1>
    translate <17.115 1.5 15>
 }


object {
    Cube
    texture {
	Tom_Wood
	dents 0.1
	scale 0.1
     }
    color White
    scale <0.04 1.2 1>
    translate <17.115 1.5 12.5>
 }


object {
    Cube
    texture {
	Tom_Wood
	dents 0.1
	scale 0.1
     }
    color White
    scale <0.04 1.2 1>
    translate <17.115 1.5 10>
 }

/* Left cabinets */

object {
    CTop
    scale <8 1 2>
    translate <16 3 19>
 }

object {
    Cube
    texture {
	Tom_Wood
	dents 0.1
	scale 0.1
     }
    color White
    scale <7.9 1.5 1.9>
    translate <16 1.5 19>
 }

/* Doors */

object {
    Cube
    texture {
	Tom_Wood
	dents 0.1
	scale 0.1
     }
    color White
    scale <1 1.2 0.04>
    translate <9.5 1.5 17.115>
 }


object {
    Cube
    texture {
	Tom_Wood
	dents 0.1
	scale 0.1
     }
    color White
    scale <1 1.2 0.04>
    translate <12.5 1.5 17.115>
 }


object {
    Cube
    texture {
	Tom_Wood
	dents 0.1
	scale 0.1
     }
    color White
    scale <1 1.2 0.04>
    translate <15.5 1.5 17.115>
 }


/* Cupboards */

object {
    Cube
    texture {
	color White
     }
    color White
    scale <1.9 2.5 2>
    translate <19 7.5 14>
 }


object {
    Cube
    texture {
	color White
     }
    color White
    scale <2 2.5 1.9>
    translate <11.7 7.5 19.3>
 }


/* Window */

object {
    Cube
    scale <1 2 0.001>
    translate <17 6 20>
    texture {
	Glass
     }
 }

object {
    BarY
    texture {
	wood
     }
    color Brown
    scale <0.05 2 0.05>
    translate <17 6 20>
 }

object {
    BarX
    texture {
	wood
     }
    color Brown
    scale <1 0.05 0.05>
    translate <17 6 20>
 }


/* Sliding glass door */

object {
    Cube
    scale <1 3 0.001>
    translate <3 3 20.1>
    texture {
	Glass
     }
 }

object {
    BarY
    texture {
	Metal
     }
    color Black
    scale <0.05 3 0.05>
    translate <4 3 20.1>
 }

object {
    Cube
    scale <1 3 0.001>
    translate <4 3 19.9>
    texture {
	Glass
     }
 }

object {
    BarY
    texture {
	Metal
     }
    color Black
    scale <0.05 3 0.05>
    translate <3 3 19.9>
 }

object {
    BarY
    texture {
	Metal
     }
    color Black
    scale <0.05 3 0.05>
    translate <5 3 19.9>
 }


/* Refrigerator  w/o doors */

object {
    difference {
        object {
          Cube
        }
	object {
	    Cube
	    scale <0.45 0.95 1>
	    translate <-0.5 0 -0.1>
	 }
	object {
	    Cube
	    scale <0.45 0.95 1>
	    translate <0.5 0 -0.1>
	 }
     }	
    texture {
	color White
	reflection 0.1
     }
    scale <1.2 3 1.5>
    rotate <0 90 0>
    translate <18.5 3.2 5>
    color White
 }

/* Left door */

object {
    Cube
    texture {
	color White
	reflection 0.01
     }
    scale <1 3 0.09>  
    rotate <0 90 0>
    translate <17 3.2 5.5>
 }

/* Right door -- partially open */

object {
    Cube
    texture {
	color White
	reflection 0.01
     }
    scale <1 3 0.09>  
    rotate <0 40 0>
    translate <16.2 3.2 4.4>
 }

/* Light in fridge  (this light stays on even if you shut the door :-) */

light_source {
  <17.0 3.2 4.4>
  color White
}

/* Picture in frame on wall.  Thanks to Tom Price for his great SNACK trace.
    NOTE: You can substitute any GIF in place of snack.gif below, but snack
	    just seemed appropriate.  It always has been a favorite of mine.
*/

composite {
    object {
        Cube
        scale <1 1 0.1>
        translate <1 1 0>
	texture {
            image_map { gif "snack.gif" once}
	    scale <2 2 2>
	 }
     }

/* The picture frame */

    object {
	BarY
	scale <0.1 1.0 0.1>
	translate <2 1 0>
        texture {
	    Pine_Wood
	    ambient 0.3
	    diffuse 0.7
	 }
     }
    object {
	BarY
	scale <0.1 1 0.1>
	translate <0 1 0>
    texture {
	Pine_Wood
	ambient 0.3
	diffuse 0.7
     }

     }
    object {
	BarX
	scale <1.0 0.1 0.1>
	translate <1 0 0>
    texture {
	Pine_Wood
	ambient 0.3
	diffuse 0.7
     }

     }
    object {
	BarX
	scale <1.0 0.1 0.1>
	translate <1 2 0>
    texture {
	Pine_Wood
	ambient 0.3
	diffuse 0.7
     }

     }
    scale <1 1 1>
    rotate <0 90 0>
    translate <19.9 6 10.0>
 }


/* Deck */

object {
    Cube
    texture {
      Tom_Wood
    }
    scale <4 0.15 3>
    translate <3 0 23>
 }

/* Microwave */

object {
    box {<0 0 0> <2 2 2>}
    texture {
	/* the next line was originally: IMAGEMAP GIF "front.gif" */
/*        image_map { gif "stars.gif" once} */
        color White
        scale <2 2 2>
     }
    scale <1 0.85 0.85>
    rotate <0 90 0>
    translate <19 3.1 11.5>
 }




